Simple bots or Simbots is a library designed to create simple bots using the power of python. This library utilises Intent,Entity,Relation and Context
model to create bots . It uses a multinomial NB classifier to create intent classifiers.